==> certmanager-model-v1beta1-5.10.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1beta1/ChallengeSpecBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ChallengeSpecBuilder extends io.fabric8.certmanager.api.model.acme.v1beta1.ChallengeSpecFluentImpl<io.fabric8.certmanager.api.model.acme.v1beta1.ChallengeSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.certmanager.api.model.acme.v1beta1.ChallengeSpec,io.fabric8.certmanager.api.model.acme.v1beta1.ChallengeSpecBuilder>{
  public ChallengeSpecBuilder() {
    this(false);
  }
  public ChallengeSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ChallengeSpec(), validationEnabled);
  }
  public ChallengeSpecBuilder(io.fabric8.certmanager.api.model.acme.v1beta1.ChallengeSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ChallengeSpecBuilder(io.fabric8.certmanager.api.model.acme.v1beta1.ChallengeSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ChallengeSpec(), validationEnabled);
  }
  public ChallengeSpecBuilder(io.fabric8.certmanager.api.model.acme.v1beta1.ChallengeSpecFluent<?> fluent,io.fabric8.certmanager.api.model.acme.v1beta1.ChallengeSpec instance) {
    this(fluent, instance, false);
  }
  public ChallengeSpecBuilder(io.fabric8.certmanager.api.model.acme.v1beta1.ChallengeSpecFluent<?> fluent,io.fabric8.certmanager.api.model.acme.v1beta1.ChallengeSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAuthorizationURL(instance.getAuthorizationURL()); 
    fluent.withDnsName(instance.getDnsName()); 
    fluent.withIssuerRef(instance.getIssuerRef()); 
    fluent.withKey(instance.getKey()); 
    fluent.withSolver(instance.getSolver()); 
    fluent.withToken(instance.getToken()); 
    fluent.withType(instance.getType()); 
    fluent.withUrl(instance.getUrl()); 
    fluent.withWildcard(instance.getWildcard()); 
    this.validationEnabled = validationEnabled; 
  }
  public ChallengeSpecBuilder(io.fabric8.certmanager.api.model.acme.v1beta1.ChallengeSpec instance) {
    this(instance,false);
  }
  public ChallengeSpecBuilder(io.fabric8.certmanager.api.model.acme.v1beta1.ChallengeSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAuthorizationURL(instance.getAuthorizationURL()); 
    this.withDnsName(instance.getDnsName()); 
    this.withIssuerRef(instance.getIssuerRef()); 
    this.withKey(instance.getKey()); 
    this.withSolver(instance.getSolver()); 
    this.withToken(instance.getToken()); 
    this.withType(instance.getType()); 
    this.withUrl(instance.getUrl()); 
    this.withWildcard(instance.getWildcard()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.certmanager.api.model.acme.v1beta1.ChallengeSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.certmanager.api.model.acme.v1beta1.ChallengeSpec build() {
    ChallengeSpec buildable = new ChallengeSpec(fluent.getAuthorizationURL(),fluent.getDnsName(),fluent.getIssuerRef(),fluent.getKey(),fluent.getSolver(),fluent.getToken(),fluent.getType(),fluent.getUrl(),fluent.getWildcard());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ChallengeSpecBuilder that = (ChallengeSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> certmanager-model-v1beta1-6.4.1-sources.jar: io/fabric8/certmanager/api/model/acme/v1beta1/ChallengeSpecBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ChallengeSpecBuilder extends ChallengeSpecFluentImpl<ChallengeSpecBuilder> implements VisitableBuilder<ChallengeSpec,ChallengeSpecBuilder>{
  public ChallengeSpecBuilder() {
    this(false);
  }
  public ChallengeSpecBuilder(Boolean validationEnabled) {
    this(new ChallengeSpec(), validationEnabled);
  }
  public ChallengeSpecBuilder(ChallengeSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ChallengeSpecBuilder(ChallengeSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ChallengeSpec(), validationEnabled);
  }
  public ChallengeSpecBuilder(ChallengeSpecFluent<?> fluent,ChallengeSpec instance) {
    this(fluent, instance, false);
  }
  public ChallengeSpecBuilder(ChallengeSpecFluent<?> fluent,ChallengeSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAuthorizationURL(instance.getAuthorizationURL()); 
    fluent.withDnsName(instance.getDnsName()); 
    fluent.withIssuerRef(instance.getIssuerRef()); 
    fluent.withKey(instance.getKey()); 
    fluent.withSolver(instance.getSolver()); 
    fluent.withToken(instance.getToken()); 
    fluent.withType(instance.getType()); 
    fluent.withUrl(instance.getUrl()); 
    fluent.withWildcard(instance.getWildcard()); 
    this.validationEnabled = validationEnabled; 
  }
  public ChallengeSpecBuilder(ChallengeSpec instance) {
    this(instance,false);
  }
  public ChallengeSpecBuilder(ChallengeSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAuthorizationURL(instance.getAuthorizationURL()); 
    this.withDnsName(instance.getDnsName()); 
    this.withIssuerRef(instance.getIssuerRef()); 
    this.withKey(instance.getKey()); 
    this.withSolver(instance.getSolver()); 
    this.withToken(instance.getToken()); 
    this.withType(instance.getType()); 
    this.withUrl(instance.getUrl()); 
    this.withWildcard(instance.getWildcard()); 
    this.validationEnabled = validationEnabled; 
  }
  ChallengeSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ChallengeSpec build() {
    ChallengeSpec buildable = new ChallengeSpec(fluent.getAuthorizationURL(),fluent.getDnsName(),fluent.getIssuerRef(),fluent.getKey(),fluent.getSolver(),fluent.getToken(),fluent.getType(),fluent.getUrl(),fluent.getWildcard());
    return buildable;
  }
  
}
